==> libgnomedb-1.3.0.tar.gz: libgnomedb-1.3.0/extra/gnome-db-verify-file.c <==
#include <libgnomedb/libgnomedb.h>

int 
main (int argc, char **argv)
{
	GnomeDbDict *dict;
	gchar *filename;
	GError *error = NULL;
	GSList *list, *lptr;
	
	if (argc <= 1) {
		g_print (_("Usage: %s <filename.xml>\n"), argv[0]);
		g_print (_("Checks that <filename.xml> id correct, and lists all the queries it contains\n"
			   "For each query, a .dot file is created, to be used with the graphviz utility\n"
			   "(http://www.graphviz.org/)"));
		exit (1);
	}

	filename = argv[1];
	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
		g_print (_("File '%s' does not exist or can't be read!\n"), filename);
		exit (2);
	}

	if (g_file_test (filename, G_FILE_TEST_IS_DIR)) {
		g_print (_("File '%s' is a directory!\n"), filename);
		exit (2);
	}
	
	g_type_init ();
	dict = GNOME_DB_DICT (gnome_db_dict_new ());
	if (!gnome_db_dict_load_xml_file (dict, filename, &error)) {
		g_print (_("Error loading file '%s':\n%s\n"), filename, error->message);
		g_error_free (error);
		exit (3);
	}

	g_print ("File '%s' has correctly been loaded.\n", filename);

	/* queries listing */
	list = gnome_db_dict_get_queries (dict);
	if (list) 
		g_print (_("List of queries in this file:\n"));
	else
		g_print (_("There is no query in this file.\n"));
	lptr = list;
	while (lptr) {
		GnomeDbGraphviz *graph;
		GnomeDbDataSet *context;
		GError *error = NULL;

		gchar *str;
		g_print (_("########### Query \"%s\" ###########\n"), gnome_db_base_get_name (GNOME_DB_BASE (lptr->data)));
		str = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (lptr->data), NULL, 
						 GNOME_DB_RENDERER_EXTRA_PRETTY_SQL | GNOME_DB_RENDERER_EXTRA_VAL_ATTRS, &error);
		g_print (_("## SQL:\n"));
		if (str) {
			g_print ("%s\n", str);
			g_free (str);
		}
		else {
			g_print (_("SQL ERROR: %s\n"), error->message);
			g_error_free (error);
			error = NULL;
		}

		g_print (_("## information:\n"));
		str = gnome_db_xml_storage_get_xml_id (GNOME_DB_XML_STORAGE (lptr->data));
		g_print ("XML Id: %s\n", str);
		g_free (str);
		context = gnome_db_entity_get_exec_dataset (GNOME_DB_ENTITY (lptr->data));
		if (!gnome_db_data_set_is_coherent (context, &error)) {
			g_print ("Generated context is not coherent: %s\n", error->message);
			g_error_free (error);
		}
		else
			g_print ("Generated context is coherent\n");
		g_object_unref (G_OBJECT (context));
		
		str = g_strdup_printf (_("Query_%02d.dot"), g_slist_position (list, lptr) + 1);
		graph = GNOME_DB_GRAPHVIZ (gnome_db_graphviz_new (dict));
		gnome_db_graphviz_add_to_graph (graph, G_OBJECT (lptr->data));
		if (!gnome_db_graphviz_save_file (graph, str, &error)) {
			g_print (_("Could not write graph to '%s' (%s)\n\n"), str, error->message);
			g_error_free (error);
			error = NULL;
		}
		else
			g_print (_("Written graph to '%s'\n\n"), str);
		g_free (str);
		
		lptr = g_slist_next (lptr);
	}
	g_slist_free (list);
	
	g_object_unref (G_OBJECT (dict));

	return 0;
}

==> libgnomedb-1.9.99.tar.gz: libgnomedb-1.9.99/extra/gnome-db-verify-file.c <==
#include <libgnomedb/libgnomedb.h>

int 
main (int argc, char **argv)
{
	GnomeDbDict *dict;
	gchar *filename;
	GError *error = NULL;
	GSList *list, *lptr;
	
	if (argc <= 1) {
		g_print (_("Usage: %s <filename.xml>\n"), argv[0]);
		g_print (_("Checks that <filename.xml> is correct, and lists all the queries it contains\n"
			   "For each query, a .dot file is created, to be used with the graphviz utility\n"
			   "(http://www.graphviz.org/)"));
		exit (1);
	}

	filename = argv[1];
	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
		g_print (_("File '%s' does not exist or can't be read!\n"), filename);
		exit (2);
	}

	if (g_file_test (filename, G_FILE_TEST_IS_DIR)) {
		g_print (_("File '%s' is a directory!\n"), filename);
		exit (2);
	}
	
	g_type_init ();
	dict = GNOME_DB_DICT (gnome_db_dict_new ());
	if (!gnome_db_dict_load_xml_file (dict, filename, &error)) {
		g_print (_("Error loading file '%s':\n%s\n"), filename, error->message);
		g_error_free (error);
		exit (3);
	}

	g_print ("File '%s' has correctly been loaded.\n", filename);

	/* queries listing */
	list = gnome_db_dict_get_queries (dict);
	if (list) 
		g_print (_("List of queries in this file:\n"));
	else
		g_print (_("There is no query in this file.\n"));
	lptr = list;
	while (lptr) {
		GnomeDbGraphviz *graph;
		GnomeDbDataSet *context;
		GError *error = NULL;

		gchar *str;
		g_print (_("########### Query \"%s\" ###########\n"), gnome_db_base_get_name (GNOME_DB_BASE (lptr->data)));
		str = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (lptr->data), NULL, 
						 GNOME_DB_RENDERER_EXTRA_PRETTY_SQL | GNOME_DB_RENDERER_EXTRA_VAL_ATTRS, &error);
		g_print (_("## SQL:\n"));
		if (str) {
			g_print ("%s\n", str);
			g_free (str);
		}
		else {
			g_print (_("SQL ERROR: %s\n"), error->message);
			g_error_free (error);
			error = NULL;
		}

		g_print (_("## information:\n"));
		str = gnome_db_xml_storage_get_xml_id (GNOME_DB_XML_STORAGE (lptr->data));
		g_print ("XML Id: %s\n", str);
		g_free (str);
		context = gnome_db_entity_get_exec_dataset (GNOME_DB_ENTITY (lptr->data));
		if (!gnome_db_data_set_is_coherent (context, &error)) {
			g_print ("Generated context is not coherent: %s\n", error->message);
			g_error_free (error);
		}
		else
			g_print ("Generated context is coherent\n");
		g_object_unref (G_OBJECT (context));
		
		str = g_strdup_printf (_("Query_%02d.dot"), g_slist_position (list, lptr) + 1);
		graph = GNOME_DB_GRAPHVIZ (gnome_db_graphviz_new (dict));
		gnome_db_graphviz_add_to_graph (graph, G_OBJECT (lptr->data));
		if (!gnome_db_graphviz_save_file (graph, str, &error)) {
			g_print (_("Could not write graph to '%s' (%s)\n\n"), str, error->message);
			g_error_free (error);
			error = NULL;
		}
		else
			g_print (_("Written graph to '%s'\n\n"), str);
		g_free (str);
		
		lptr = g_slist_next (lptr);
	}
	g_slist_free (list);
	
	g_object_unref (G_OBJECT (dict));

	return 0;
}
